# cminpack_numba

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

A numba wrapper of cminpack.

## Installation

```shell
pip install cminpack_numba
```
